package nxtbluetooth;

import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.IOException;
import lejos.nxt.*;
import lejos.nxt.comm.*;

/**
 * Komunikacni trida NXT s PC.
 *
 * @author Michael
 */
public class Comm {
    
    private NXTConnection connection;
    private DataInputStream dis;
    private DataOutputStream dos;
    private boolean connectedToBT;
    
    /**
     * Konstruktor zavadejici spojeni pres BT(Bluetooth) ci USB.
     */
    public Comm() {
        Main.printToLCD("USB < | > BT", 0);

        if(Button.waitForAnyPress() == Button.ID_RIGHT){
            Main.printToLCD("Waiting for BT", 0);
            connection = Bluetooth.waitForConnection();
            Main.printToLCD("Connected to BT", 0);
            connectedToBT = true;
        } else {
            Main.printToLCD("Waiting for USB", 0);
            connection = USB.waitForConnection();
            Main.printToLCD("Connected to USB", 0);
            connectedToBT = false;
        }
    }
    
    /**
     * Pro zjisteni, zda je spojeni navazane pres BT nebo USB.
     * @return true pokud pres BT
     */
    private boolean isConnectedToBT() {
        return connectedToBT;
    }
    
    /**
     * Zacne naslouchat pres DataInputStream.
     */
    public void setDataInputStream() {
        dis = connection.openDataInputStream();
    }
    
    /**
     * Pripravi se na odesilani packetu pres DataOutputStream.
     */
    public void setDataOutputStream() {
        dos = connection.openDataOutputStream();
    }
    
    /**
     * Ziska cislo z prichoziho packetu. POZN.: ceka, nez dojde nejaky packet.
     * @return Cislo z Packetu.
     * @throws IOException
     */
    public int getPacketInt() throws IOException {
        return dis.readInt();
    }
    
    /**
     * Ziska String z prichoziho packetu. POZN.: ceka, nez dojde nejaky packet.
     * @return String z packetu.
     * @throws IOException 
     */
    public String getPacketString() throws IOException {
        return dis.readUTF();
    }
    
    /**
     * Odesle cislo v packetu.
     * @param i Cislo k odeslani.
     */
    public void sendPacket(int i) {
        try {
            dos.writeInt(i);
            dos.flush();
        } catch (IOException ex) {
            Main.printToLCD("Send err", 3);
        }
    }
    
    /**
     * Odesle String v packetu.
     * @param s String k odeslani.
     */
    public void sendPacket(String s) {
        try {
            dos.writeUTF(s);
            dos.flush();
        } catch (IOException ex) {
            Main.printToLCD("Send err", 3);
        }
    }
    
    /**
     * Uzavre vsechny streamy a spojeni.
     */
    public void closeAllConnections() {
        try {
            dos.close();
            dis.close();
            connection.close();
            Main.printToLCD("Disconnected", 3);
            Button.waitForAnyPress();
        } catch(IOException io) {
            Main.printToLCD("Disconnection err", 3);
        }
    }
    
    /**
     * Znovunavazani ztraceneho spojeni.
     */
    public void reconnect() {
        Main.printToLCD("Connection lost...", 1);
        Main.printToLCD("Reconnecting...", 3);

        if(connectedToBT) {
            connection = Bluetooth.waitForConnection();
        } else {
            connection = USB.waitForConnection();
        }

        Main.printToLCD("Reconnected", 1);
        Main.printToLCD("", 1);
    }
}
