package nxtbluetooth;

import lejos.nxt.SensorPort;
import lejos.nxt.UltrasonicSensor;

/**
 * Trida fungujici jako vlakno. Stara se o fungovani "Ultrasonic Sensoru".
 * V urcitem intervalu "pinka" (vysila zvukove signaly) a na zaklade vracenych
 * odrazu aktualizuje promenou "isClear".
 *
 * @author Michael
 */
public class SonicSensor implements Runnable {

    private static final int DELAY = 500;
    private static final float MIN_RANGE = 20;
    
    private UltrasonicSensor us;
    private boolean run;
    private static boolean isClear;
    
    /**
     * Konstruktor. Nastavi senzor do modu "PING".
     */
    public SonicSensor() {
        us = new UltrasonicSensor(SensorPort.S1);
        us.setMode(us.MODE_PING);
        run = true;
        isClear = true;
    }

    /**
     * Vraci obsah promene rikajici, zda je cesta volna.
     * @return True pokud neni pred cidlem prekazka.
     */
    public boolean isPathClear() {
        return isClear;
    }
    
    /**
     * Pokusi se zastavit vlakno regulernim zpusobem.
     */
    public void requestStop() {
        run = false;
    }

    /**
     * Hlavni spousteci metoda vlakna.
     */
    public void run() {
        while(run) {
            try {
                us.ping();
                Thread.sleep(26);
                isClear = us.getRange() > MIN_RANGE;
                Thread.sleep(DELAY);
            } catch (InterruptedException ex) {
                // nothing to do
            }
        }
    }
    
}
